@@ -23,7 +23,8 @@ class HttpEndpoint:
             endpoint_url: str,
             method: str,
             body: Optional[Union[Dict[Any, Any], Iterable[Any], AnyStr]] = None,
-            headers: Optional[Dict[str, str]] = None
+            headers: Optional[Dict[str, str]] = None,
+            fields: Optional[Any] = None
     ) -> None:
         """
         Constructor.
@@ -32,11 +33,16 @@ class HttpEndpoint:
         :param method: Http request method type.
         :param body: Body to include in request.
         :param headers: Headers to include in request.
+        :param fields: Fields can be one of the following:
+            # Regular query parameters or request body { key: value } pairs.
+            # Multi-value query parameters [ (key: value1), (key: value2) ] for reused key argument.
+            # Filetuple, read more it here: https://urllib3.readthedocs.io/en/latest/reference/urllib3.request.html#urllib3.request.RequestMethods.urlopen
         """
         self.__endpoint_url = endpoint_url
         self.__http_method = method
         self.__http_body = body
         self.__headers = headers or {}
+        self.__fields = fields
 
         assert isinstance(self.__endpoint_url, str), 'Expected string.'
         assert self.__http_method in ['GET', 'POST', 'PUT', 'DELETE', 'HEAD', 'OPTIONS'], 'Unsupported method.'
@@ -58,7 +64,7 @@ class HttpEndpoint:
 
         :return: Http response represented as dictionary.
         """
-        data = self.__call().data
+        data = self._call().data
 
         if data == b'':
             return {}
@@ -71,7 +77,7 @@ class HttpEndpoint:
 
         :return: Http response represented as bytes.
         """
-        return self.__call().data
+        return self._call().data
 
     def call_to_str(self) -> str:
         """
@@ -79,7 +85,7 @@ class HttpEndpoint:
 
         :return: Http response represented as string.
         """
-        data = self.__call().data
+        data = self._call().data
         encodings = ['utf-8', 'ISO-8859-1', 'Windows-1251', 'Windows-1252']
 
         for en in encodings:
@@ -96,9 +102,9 @@ class HttpEndpoint:
 
         :return: Http response.
         """
-        return self.__call()
+        return self._call()
 
-    def __call(self) -> HTTPResponse:
+    def _call(self) -> HTTPResponse:
         """
         Initiates a call to a specified endpoint with specified parameters.
 
@@ -107,6 +113,7 @@ class HttpEndpoint:
         return HttpCall.call(
             method=self.http_method,
             url=self.endpoint_url,
+            fields=self.fields,
             headers=self.headers,
             body=self.http_body
         )
@@ -167,3 +174,13 @@ class HttpEndpoint:
             **headers,
             **(self.__headers or {})
         }
+
+    @property
+    def fields(self) -> Optional[Any]:
+        """
+        An appropriate encoding of fields based on the HTTP method used when performing the request.
+        An http request using urllib3.request.urlopen will be made using these fields.
+
+        :return: Fields parameter.
+        """
+        return self.__fields
